@@ -3,7 +3,19 @@
 
 #define PACKAGE				"newsboat"
 #define PROGRAM_NAME			PACKAGE
-#define REAL_VERSION "2.10.2"
+
+#define STRINGIFY_HELPER(str) #str
+#define STRINGIFY(str) STRINGIFY_HELPER(str)
+
+#define NEWSBOAT_VERSION_MAJOR 2
+#define NEWSBOAT_VERSION_MINOR 10
+#define NEWSBOAT_VERSION_PATCH 2
+#define REAL_VERSION \
+	STRINGIFY(NEWSBOAT_VERSION_MAJOR) \
+	"." \
+	STRINGIFY(NEWSBOAT_VERSION_MINOR) \
+	"." \
+	STRINGIFY(NEWSBOAT_VERSION_PATCH)
 
 #ifdef GIT_HASH
 #define PROGRAM_VERSION			GIT_HASH
