@@ -1,5 +1,5 @@
 #define CATCH_CONFIG_RUNNER
-#include "catch.hpp"
+#include "3rd-party/catch.hpp"
 
 #include <logger.h>
 
